/*
 * See Licensing and Copyright notice in naev.h
 */
#pragma once

#include "nlua.h"

/*
 * Lua control
 */
int nlua_loadMusic( nlua_env *env );
